searchData={"items":[{"type":"module","title":"DryValidation","doc":"Used to create a schema to validate input data against.","ref":"DryValidation.html"},{"type":"module","title":"Example - DryValidation","doc":"```\niex> alias DryValidation.Types\n...>\niex> schema = DryValidation.schema do\n...>  required :name, Types.String\n...>  optional :age, Types.Integer\n...> end\n...>\niex> input_data = %{\"name\" => \"John\", \"age\" => \"15\"}\niex> {:ok, output_data} = DryValidation.Validator.validate(schema, input_data)\niex> assert output_data == %{\"name\" => \"John\", \"age\" => 15}\n...>\niex> input_data = %{\"name\" => 15, \"age\" => \"nonsense\"}\niex> {:error, error} = DryValidation.Validator.validate(schema, input_data)\niex> assert error == %{\n...>  \"name\" => \"15 is not a valid type; Expected type is DryValidation.Types.String\",\n...>  \"age\" => ~s(\"nonsense\" is not a valid type; Expected type is DryValidation.Types.Integer)\n...> }\n```\n\nComplex schemas can be crafted using the methods - `required`, `optional`, `map` and `map_list`.\nWith the use the provided `DryValidation.Types`, requirements can be set and also cast values when possible.","ref":"DryValidation.html#module-example"},{"type":"module","title":"Available Types - DryValidation","doc":"Type          | Description\n------------- | -------------\n`DryValidation.Types.String`  | Expects a string type `\"some text\"`. Will try to cast the value into a string (`1001` = `\"1001\"`).\n`DryValidation.Types.Bool`    | Expects a boolean type `[true/false]`. Will cast the strings \"true\"/\"false\" to real booleans\n`DryValidation.Types.Float`   | Expects a float type `[15.51]`. Will try to cast a string to a float (`\"15.5\"` = `15.5`).\n`DryValidation.Types.Integer` | Expects an integer type `[101]`. Will try to cast a string to an integer (`\"100\"` = `100`). It'll fail the cast if the string is a float.\n`DryValidation.Types.Func`    | Custom rules can be build using this, see the module docs. Example is the `DryValidation.Types.Integer.greater_than(5)` rule.\n`DryValidation.Types.List`    | Expects a list. Can have the list type set to one of the above, including a `Func`.\n`DryValidation.Types.Any`     | Accepts any value and will do no casting. Usually not used as the type can just be omitted when using `optional` and `required`","ref":"DryValidation.html#module-available-types"},{"type":"module","title":"Advanced example - DryValidation","doc":"```\nschema = DryValidation.schema do\n  required :name, Types.String\n  required :age, Types.Integer.greater_than(18)\n  required :type, Types.Func.equal(\"users\")\n  optional :pets, Types.Func.member_of([\"dog\", \"cat\", \"bird\"])\n  optional :favourite_numbers, Types.List.type(Types.Integer)\n\n  map_list :cars do\n    required :make, Types.String\n    required :cc, Types.Integer\n  end\n\n  map :house, optional: true do\n    required :address, Types.String\n  end\nend\n\ninput_data = %{\n  \"name\" => \"Jon Snow\",\n  \"age\" => 42,\n  \"type\" => \"users\",\n  \"pet\" => \"dog\",\n  \"favourite_numbers\" => [],\n  \"cars\" => [\n    %{\"make\" => \"AUDI\", \"cc\" => 3000},\n    %{\"make\" => \"BMW\", \"cc\" => 2000},\n  ],\n  \"house\" => %{\n    \"address\" => \"Church Road\"\n  }\n}\n{:ok, _output_data} = DryValidation.Validator.validate(schema, input_data)\n```","ref":"DryValidation.html#module-advanced-example"},{"type":"macro","title":"DryValidation.map/3","doc":"Defines a map. Can be made optional.\n```\nschema = DryValidation.schema do\n  map :user, do\n    required(:name, Types.String)\n  end\n\n  map :car, optional: true do\n    required(:name, Types.String)\n  end\nend\n\ninput_data = %{\"user\" => %{\"name\" => \"John\"}}\n{:ok, output_data} = DryValidation.Validator.validate(schema, input_data)\n```","ref":"DryValidation.html#map/3"},{"type":"macro","title":"DryValidation.map_list/3","doc":"Defines a list of maps. Can be made optional.\n```\nschema = DryValidation.schema do\n  map_list :users, do\n    required(:name, Types.String)\n  end\nend\n\ninput_data = %{\"users\" => [%{\"name\" => \"John\"}, %{\"name\" => \"Bob\"}]}\n{:ok, output_data} = DryValidation.Validator.validate(schema, input_data)\n```","ref":"DryValidation.html#map_list/3"},{"type":"macro","title":"DryValidation.optional/2","doc":"Defines an optional attribute in the schema.\n  First argument is the name of the attribute, second argument is optional and defines the type.\n  ```\n  schema = DryValidation.schema do\n    required(:name)\n    optional(:age)\n  end\n\n  input_data = %{\"name\" => \"Jon\"}\n  {:ok, output_data} = DryValidation.Validator.validate(schema, input_data)\n  output_data == %{\"name\" => \"Jon\"}\n  ```","ref":"DryValidation.html#optional/2"},{"type":"macro","title":"DryValidation.required/2","doc":"Defines a mandatory attribute in the schema.\n  First argument is the name of the attribute, second argument is optional and defines the type.\n  ```\n  schema = DryValidation.schema do\n    required(:name, Types.String)\n    optional(:age)\n  end\n\n  input_data = %{\"age\" => 21}\n  {:error, errors} = DryValidation.Validator.validate(schema, input_data)\n  errors == %{\"name\" => \"Is missing\"}\n  ```","ref":"DryValidation.html#required/2"},{"type":"macro","title":"DryValidation.schema/1","doc":"Creates a validation schema.","ref":"DryValidation.html#schema/1"},{"type":"module","title":"DryValidation.Types.Any","doc":"Represents any type, will not cast the value and will always assume that the value is valid.\nDryValidation.schema do\n  required :anything, Types.Any\nend","ref":"DryValidation.Types.Any.html"},{"type":"module","title":"DryValidation.Types.Bool","doc":"Represents a boolean type.\nWill cast the strings \"true\" and \"false\" into real boolean values.\n```\nDryValidation.schema do\n  required :admin, Types.Bool\nend\n```","ref":"DryValidation.Types.Bool.html"},{"type":"module","title":"DryValidation.Types.Date","doc":"Represents a boolean type.\nWill cast the strings \"true\" and \"false\" into real boolean values.\n```\nDryValidation.schema do\n  required :admin, Types.Bool\nend\n```","ref":"DryValidation.Types.Date.html"},{"type":"module","title":"DryValidation.Types.Float","doc":"Represents a float type.\nWill try to cast strings into float values.\n```\nDryValidation.schema do\n  required :price, Types.Float\nend\n```","ref":"DryValidation.Types.Float.html"},{"type":"module","title":"DryValidation.Types.Func","doc":"Provides a way to define custom validation functions.\nIt is a struct with:\n* `fn` that stores a function with one argument, that is used validate the input value\n* `type` is optional, used for casting values against that type before validating\n* `error_message` is error message returned in case of failed validation\n\n```\nDryValidation.schema do\n  required :pet, Types.Func.member_of([\"dog\", \"cat\", \"bird\"])\nend\n```","ref":"DryValidation.Types.Func.html"},{"type":"function","title":"DryValidation.Types.Func.cast/2","doc":"","ref":"DryValidation.Types.Func.html#cast/2"},{"type":"function","title":"DryValidation.Types.Func.equal/1","doc":"Validates that the input value is equal to the first argument.\n```\nDryValidation.schema do\n  required :type, Types.Func.equal(\"user\")\nend\n```","ref":"DryValidation.Types.Func.html#equal/1"},{"type":"function","title":"DryValidation.Types.Func.member_of/1","doc":"Validates that the value is part of the list.\n```\nDryValidation.schema do\n  required :pet, Types.Func.member_of([\"dog\", \"cat\", \"bird\"])\nend\n```","ref":"DryValidation.Types.Func.html#member_of/1"},{"type":"module","title":"DryValidation.Types.Integer","doc":"Represents an integer type.\nWill try to cast strings into integer values.\n```\nDryValidation.schema do\n  required :age, Types.Integer\nend\n```","ref":"DryValidation.Types.Integer.html"},{"type":"function","title":"DryValidation.Types.Integer.greater_than/1","doc":"Validates that the input value is greater than the value of the first function argument.\n```\nDryValidation.schema do\n  required :age, Types.Integer.greater_than(18)\nend\n```","ref":"DryValidation.Types.Integer.html#greater_than/1"},{"type":"function","title":"DryValidation.Types.Integer.greater_than_or_equal/1","doc":"Validates that the input value is greater than or equal to the value of the first function argument.\n```\nDryValidation.schema do\n  required :age, Types.Integer.greater_than_or_equal(18)\nend\n```","ref":"DryValidation.Types.Integer.html#greater_than_or_equal/1"},{"type":"function","title":"DryValidation.Types.Integer.less_than/1","doc":"Validates that the input value is less than the value of the first function argument.\n```\nDryValidation.schema do\n  required :age, Types.Integer.less_than(100)\nend\n```","ref":"DryValidation.Types.Integer.html#less_than/1"},{"type":"function","title":"DryValidation.Types.Integer.less_than_or_equal/1","doc":"Validates that the input value is less than or equal to the value of the first function argument.\n```\nDryValidation.schema do\n  required :age, Types.Integer.less_than_or_equal(100)\nend\n```","ref":"DryValidation.Types.Integer.html#less_than_or_equal/1"},{"type":"module","title":"DryValidation.Types.List","doc":"Represents a list of elements. Type or a function can also be specified.\n```\nDryValidation.schema do\n  required :words, Types.List.type(Types.String)\n  required :numbers, Types.List.type(Types.Integer)\n  required :numbers_greater_than_ten, Types.List.type(Types.Integer.greater_than(10))\nend\n```","ref":"DryValidation.Types.List.html"},{"type":"function","title":"DryValidation.Types.List.type/1","doc":"Specify the required type of the elements within the list.","ref":"DryValidation.Types.List.html#type/1"},{"type":"module","title":"DryValidation.Types.String","doc":"Represents a string type.\n```\nDryValidation.schema do\n  required :name, Types.String\nend\n```","ref":"DryValidation.Types.String.html"},{"type":"module","title":"DryValidation.Validator","doc":"Contains the schema validation logic.","ref":"DryValidation.Validator.html"},{"type":"function","title":"DryValidation.Validator.validate/2","doc":"Validates a schema agains an input map.","ref":"DryValidation.Validator.html#validate/2"}],"content_type":"text/markdown"}